import { Route, Routes } from '@solidjs/router';
import { Component, createEffect, createSignal, lazy } from 'solid-js';
import { loggedInUser } from './pages/Login';
import { createStore, Store, SetStoreFunction } from 'solid-js/store';
import Navbar from './ui/Navbar';
import { Todo } from './pages/Home';
// Only load the components if we are navigating to them
const Home = lazy(() => import('./pages/Home'));
const Login = lazy(() => import('./pages/Login'));
const Test = lazy(() => import('./pages/Test'));

export type User = {
  id: string;
  login: string;
};

// Helper funciton to get a global state
// https://stackoverflow.com/a/72339551
export const createGlobalStore = <T extends object>(
  init: T
): [Store<T>, SetStoreFunction<T>] => {
  const [state, setState] = createStore(init);
  if (localStorage.globalStore) {
    try {
      setState(JSON.parse(localStorage.globalStore));
    } catch (err) {
      setState(() => init);
    }
  }
  createEffect(() => {
    localStorage.globalStore = JSON.stringify(state);
  });
  return [state, setState];
};

const [store, setStore] = createGlobalStore({
  user: { id: '', login: '' } as User,
  todos: [] as Todo[],
});

const App: Component = () => {
  return (
    <>
      <Navbar />
      <Routes>
        <Route path={'test'} component={Test} />
        <Route path={['login', 'register']} component={Login} />
        <Route path={['/', '*']} component={Home} />
      </Routes>
    </>
  );
};

export { store, setStore };
export default App;
